var _ = require('underscore');

// takes in a collection returned from htmlparser.parseDOM, which creates an object for each DOM element
// searches each object for a 'script' tag
// if it has one it looks in the first element in the object's 'children' value (which is an array with only one element)
// and looks for 'SK_SVGData = \'' which is where the svg data is
// grabs the svg data, converts it to the correct format using eval, and adds it to the results array
// when done it returns the results array
module.exports = {
  getSvgs: function (collection) {
    var result = [];
    if (Array.isArray(collection)) {
      _.each(collection, function (element) {
        result = result.concat(module.exports.getSvgs(element));
      });
    } else {
      if (collection.type === 'script' && collection.children[0] && collection.children[0].data) {
        var svgScript = collection.children[0].data;
        if (svgScript.indexOf('SK_svgData = \'') > -1) {
          var startIndex = svgScript.indexOf('SK_svgData = \'') + 14;
          var endIndex = svgScript.indexOf('; SK_modelChunkLoadStart', startIndex) - 1;
          var svgData = svgScript.substring(startIndex, endIndex);
          var svg = eval('"' + svgData + '"');
          result.push(svg);
        }
      }
      if (collection.children) {
        result = result.concat(module.exports.getSvgs(collection.children));
      }
    }
    return result;
  },
  
  getDocDataArray: function (collection) {
    var result = [];
    if (Array.isArray(collection)) {
      _.each(collection, function (element) {
        result = result.concat(module.exports.getDocDataArray(element));
      });
    } else {
      if (collection.type === 'script' && collection.children[0] && collection.children[0].data) {
        var script = collection.children[0].data;
        if (script.indexOf('docData') > -1) {
          var startIndex = script.indexOf('docData') + 9;
          var endIndex = script.indexOf('start', startIndex)  - 2;
          var stuff = script.substring(startIndex, endIndex);
          result.push(stuff);
        }
      }
      if (collection.children) {
        result = result.concat(module.exports.getDocDataArray(collection.children));
      }
    }
    return result;
  },

  getIdsWithEffects: function (docDataArray) {
    var arr = JSON.parse(docDataArray)[1];
    var result = [];
    arr.forEach(function (subArr) {
      var thisRes = [];
      var flatArr = _.flatten(subArr);
      flatArr.forEach(function (element) {
        if (typeof element === 'string' && element.indexOf('g') === 0 && element.slice(-2) !== '_0') {
          thisRes.push(element);
        }
      });
      result.push(thisRes);
    });
    return result;
  }
}
