var request = require('request');
var htmlparser = require("htmlparser2");
var helpers = require('./htmlTraverserHelpers');

module.exports = {
  // takes a url
  // the raw html from a url is passed into the callback, node style
  getHtml: function (url, callback) {
    request(url, function (error, response, body) {
      if (error) {
        callback(error);
      } else {
        callback(null, body);
      }
    });
  },

  // takes a string of raw html
  // converts it to a collection using htmlparser
  // and traverses the collection and gets the svg elements from it using the htmlTraverser
  // returns array of svgs
  // not async so simply returns result
  convertHtmlToSvgs: function (rawHtml) {
    var dom = htmlparser.parseDOM(rawHtml);
    return helpers.getSvgs(dom);
  },

  // takes a url
  // an array of the svgs on that url location is passed into the callback, node style
  getSvgsFromUrl: function (url, callback) {
    module.exports.getHtml(url, function (error, html) {
      if (error) {
        callback(error);
      } else {
        var result = module.exports.convertHtmlToSvgs(html);
        callback(null, result);
      }
    });
  },

  // takes a string of raw html
  // converts it into a collection using htmlparser
  // and traverses the collection and gets the IDs of the elements inside the svgs that have effects on them
  // returns an array of one array for each page in the presentation: each subarray is the list of IDs with effects on that page
  // ids include everything including if slide transitions have effects
  convertHtmlToEffectIds: function (html) {
    var dom = htmlparser.parseDOM(html);
    var effectsNestedArray = helpers.getDocDataArray(dom);
    return helpers.getIdsWithEffects(effectsNestedArray);
  },

  // takes a url
  // an array of arrays (one per page in presentation) with IDs of the svg elements with effects on them
  // is passed into the callback, node style
  getEffectsFromUrl: function (url, callback) {
    module.exports.getHtml(url, function (error, html) {
      if (error) {
        callback(error);
      } else {
        var result = module.exports.convertHtmlToEffectIds(html);
        callback(null, result);
      }
    });
  },

  // takes a string of raw html
  // returns an array of arrays (one per page in presentation) with ids of the svg elements with effects on them, ordered by effect sequence
  // ids only include element effects, not slide transition effects
  convertHtmlToElementEffects: function (html) {
    var svgs = module.exports.convertHtmlToSvgs(html);
    var IDs = module.exports.convertHtmlToEffectIds(html);
    var result = [];
    IDs.forEach(function (IdList, index) {
      var thisResult = [];
      IdList.forEach(function (id) {
        if (svgs[index].indexOf(id) > -1) {
          var priorText = svgs[index].substr(svgs[index].indexOf(id) - 14, 14);
          if (priorText !== '<clipPath id="') {
            thisResult.push(id);
          }
        }
      });
      result.push(thisResult);
    });
    return result;
  },

  // takes a url and a callback
  // an array of arrays (one per page in presentation) with ids of the svg elements with effects on them, ordered by effect sequence,
  // is passed into callback, node style
  // ids only include element effects, not slide transition effects
  getElementEffectsFromUrl: function (url, callback) {
    module.exports.getHtml(url, function (error, html) {
      if (error) {
        callback(error);
      } else {
        var result = module.exports.convertHtmlToElementEffects(html);
        callback(null, result);
      }
    });
  }
};
